# Generated by Django 4.1.6 on 2023-02-20 15:05

from django.db import migrations, models
import wagtail.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ReusableForm',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('form_content', wagtail.fields.StreamField([], use_json_field=False)),
            ],
        ),
    ]
